# EsisteAccessoGetQueryParamMethodNotAllowedError

Method Not Allowed


## Fields

| Field              | Type               | Required           | Description        |
| ------------------ | ------------------ | ------------------ | ------------------ |
| `title`            | *Optional[str]*    | :heavy_minus_sign: | N/A                |
| `detail`           | *Optional[str]*    | :heavy_minus_sign: | N/A                |